# dagster-evidence

`dagster-evidence` provides a Dagster Component that integrates with [evidence](https://evidence.dev/), an open-source tool for building data apps.

## Test

```sh
make test
```

## Build

```sh
make build
```
